@@ -23,4 +23,12 @@ class FileIsADirectoryException(Exception):
 
 
 class NotEnoughTransferException(Exception):
-    pass
\ No newline at end of file
+    pass
+
+
+class ParentFolderDoesntExistException(Exception):
+    pass
+
+
+class CannotDeleteFileException(Exception):
+    pass
